
# q-expansion of newform 656.2.be.e, downloaded from the LMFDB on 03 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 656
weight = 2
poly_data = [256, 0, 4032, 0, 17856, 0, 28236, 0, 16529, 0, 4428, 0, 594, 0, 39, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[2336, -4448, 7896, -9308, 1148, 3221, -3361, 4812, -1780, 1330, -354, 139, -31, 5, -1, 0], 576], [[-21888, 135488, -174208, 292800, -361504, 99584, -211010, -33901, -49416, -24148, -5116, -4854, -214, -415, -2, -13], 9216], [[-10816, 0, -49408, 0, -47456, 0, -43311, 0, -21148, 0, -4594, 0, -437, 0, -15, 0], 2304], [[2176, 8640, 11008, 87104, 38816, 180752, 35526, 105505, 13336, 24708, 2356, 2558, 194, 107, 6, 1], 4608], [[2176, -8640, 11008, -87104, 38816, -180752, 35526, -105505, 13336, -24708, 2356, -2558, 194, -107, 6, -1], 4608], [[-17280, -46528, -174208, -225920, -361504, -408960, -211010, -254321, -49416, -70564, -5116, -9710, -214, -651, -2, -17], 9216], [[-17280, 46528, -174208, 225920, -361504, 408960, -211010, 254321, -49416, 70564, -5116, 9710, -214, 651, -2, 17], 9216], [[-6528, -10944, -71936, -87104, -184832, -180752, -162274, -105505, -63816, -24708, -11996, -2558, -1046, -107, -34, -1], 4608], [[10880, 24640, -47872, -76992, -343136, -460496, -264786, -331313, -77896, -91844, -10780, -11934, -710, -731, -18, -17], 9216], [[22400, 98624, 455936, 416896, 1051552, 607536, 711042, 340723, 213128, 88844, 31868, 11674, 2326, 753, 66, 19], 9216], [[11136, 139968, 27520, 748672, -76544, 1014304, -140398, 523505, -70776, 124260, -14852, 14542, -1370, 811, -46, 17], 9216], [[21888, 61760, 174208, 540992, 361504, 1115488, 211010, 715347, 49416, 201836, 5116, 28202, 214, 1921, 2, 51], 9216], [[-84352, -232768, -733568, -1563456, -1507968, -2881888, -1008674, -1757959, -304840, -474556, -46172, -63234, -3414, -4093, -98, -103], 9216], [[84352, -232768, 733568, -1563456, 1507968, -2881888, 1008674, -1757959, 304840, -474556, 46172, -63234, 3414, -4093, 98, -103], 9216]]

hecke_ring_character_values = [[575, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [165, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [129, [0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, -1, 0, 0, 1, 0, 0, -1, 0, 1, 0, 0, 0], [0, 1, 0, 0, 0, 1, -1, 0, 0, 1, 0, 0, 0, 0, 0, 1], [0, 0, 0, -2, 0, 0, 1, 0, 0, 0, 0, 1, 0, -2, -1, -1], [0, 1, 0, -1, 0, 1, 0, -1, 0, 1, 0, 1, 0, 0, 0, 0], [0, 0, 0, -1, 0, 0, 1, 0, 1, 0, 0, 0, 0, -2, -1, 0], [-2, -1, -2, 0, -1, -1, 1, 2, 2, -1, -1, -1, 1, 2, 0, 0], [-1, 0, 0, 1, 0, 0, 0, -1, 1, 0, 1, -1, -1, 1, 0, 2], [0, 0, 0, 0, -1, 0, -1, 2, 1, 1, 1, 0, 0, 3, 0, 0], [0, 0, 1, 0, 1, -2, 1, 0, 0, -2, 0, -2, 0, -1, -2, -2], [0, 0, 1, -1, 1, 0, -1, -1, -1, -1, 1, 0, -1, -1, 0, 1], [-1, 1, 1, -1, 0, -1, 1, -1, 0, -1, 1, 1, 0, 0, -1, -1], [4, 1, -1, 0, 0, -1, 0, -2, -4, 0, -1, 0, 1, -3, 0, 0], [-1, -1, -1, -1, -2, -1, 0, -1, -1, 0, 0, 1, 2, 2, 1, 0], [4, 0, -1, 1, 0, 1, -1, -5, -3, 1, 0, -1, -1, 0, -1, 1], [-2, 1, 1, 0, 0, 3, -4, 2, 2, 2, 1, 0, -1, 3, 0, 0], [-5, -2, 0, 2, -1, 0, -2, 5, 0, 0, -1, 0, 1, 5, 2, 1], [1, 0, -1, 0, 1, 2, 1, 3, 1, -1, -1, 1, -1, 3, 1, 0], [-2, -2, -1, 0, 1, 0, 0, 2, 4, -2, 0, 0, 0, -1, 0, 0], [2, 0, 0, 0, 2, 1, 1, 3, 3, 0, 0, 0, 0, 0, 1, -1], [1, 2, 1, 0, 1, -1, 1, -3, 0, 0, 1, 0, -2, -2, 1, 1], [1, 1, 2, -1, 1, 1, -1, -3, -1, 2, 2, 2, 0, -1, 1, -1], [-3, -2, 0, 0, 1, 0, 2, 3, 6, 0, 0, 2, 1, 3, 0, 0], [-1, 0, 0, 1, 1, -1, 0, -2, -1, 0, -1, 1, 0, -3, 1, 1], [0, -1, 0, 0, 1, -5, 1, 2, 2, -5, 0, -4, 1, 1, 0, 1], [1, -1, 0, 2, -2, -2, -1, -1, 0, 2, -1, 1, 2, -1, 4, 1], [4, 2, 0, -4, -1, 0, 2, -4, 0, 0, -3, 1, 1, -2, -2, -2], [-2, 0, 1, -3, 1, -3, 3, -2, 5, 0, 1, 0, -2, 1, -1, -1], [0, -1, 0, -1, 0, -4, 2, 1, -2, -3, 0, -4, -1, -3, -3, -4], [4, 0, 0, 2, 1, 0, -2, 0, 1, -2, 1, 0, 0, -1, 0, -2], [0, 2, 0, -1, 0, 2, -1, -2, 7, 0, 0, -1, -1, 6, 0, -1], [1, -1, -1, 0, -1, 1, -1, -2, 1, 0, -1, 0, 2, -2, 2, 2], [3, 1, 0, 2, -2, 0, 1, -3, 0, 0, -3, -1, 2, -7, 0, 1], [-1, 0, -2, 0, 0, 2, 3, 2, 0, -3, 0, 4, -2, 1, 4, 0], [-1, 0, 0, 1, 0, 0, 0, -3, -1, 1, -1, -1, -1, 3, -2, 0], [9, 0, 4, 0, 2, -3, 0, -1, -6, -3, 2, -1, -2, -5, 0, -2], [-4, -3, 2, 0, 0, -3, 3, 0, 2, -6, 2, 0, 0, 0, 4, -4], [2, -1, 1, 1, 0, -1, 1, 2, -7, 0, -1, 0, 0, -5, 0, 0], [-7, 2, 0, -3, 0, 6, 2, 1, 1, 4, 0, 6, 0, -3, 2, -2], [-3, 0, -1, 3, 2, 2, -1, 13, 6, 1, -2, -4, -1, 11, -4, 3], [10, 1, 0, 1, 2, 0, -3, -5, 0, 1, 2, 0, -1, -7, 1, 0], [-3, 3, 2, -3, 1, 0, 0, 5, -1, 0, 0, 0, -2, 1, -1, -1], [-3, 0, 0, -3, 2, 0, 2, 10, 5, -2, -2, 0, 0, 2, 0, -3], [0, -4, -2, -1, -2, -4, 2, 0, -3, 0, 0, 0, 2, -2, 1, 0], [1, 0, 0, -3, 0, 0, 0, -1, 1, 0, -3, 3, -3, -5, 0, 0], [-4, -2, -1, -2, -2, -2, 0, -2, -4, 2, -3, 2, -1, -1, -2, 0], [-1, -2, 4, -1, 0, 0, 2, 3, 1, -1, 1, 1, -1, 3, 0, -2], [-1, 0, -2, 0, 0, 2, 0, 1, 0, 2, -1, 1, 2, 1, 0, 3], [0, 1, -3, 6, -1, 0, -5, 3, -3, 1, -4, -5, 2, 8, 1, 5], [0, 2, 1, -3, 2, 2, 0, -1, 0, 4, 2, 3, 0, -2, -4, 0], [-10, -5, 2, 0, -1, -2, 5, -10, 2, -2, 1, 3, -3, 0, 0, -4], [1, 0, 0, 1, -4, 0, 2, 0, 7, 2, -4, 0, 0, -4, 0, -1], [-3, 6, -5, -2, -3, 3, 0, 5, -1, 6, -3, 1, 5, 3, -1, 0], [14, -3, -1, 4, 1, 0, 0, -6, -6, -3, 0, 0, 0, -3, 4, 0], [-6, -4, 1, 2, -1, 0, -1, 2, 0, -4, 0, -2, 0, 7, 0, 2], [0, 0, 4, -1, 0, 2, -2, 5, 0, 1, 4, 1, -4, 8, 0, -2], [1, -4, 0, 6, 2, -1, -4, -1, 0, 1, 5, -3, -2, 13, 0, 3], [0, -1, -2, 4, -2, 0, 0, 2, -2, 1, 0, 4, 5, 4, 0, 4], [-2, 1, 0, -1, 0, 1, 0, 5, -2, 2, 0, 1, 0, -6, 0, 0], [1, -2, 3, 0, 5, -1, -1, -3, 1, -3, 5, -1, -3, 1, 1, 2], [5, -1, -2, 0, -4, -1, 0, 2, 5, 1, -2, 0, 2, 0, -2, 0], [9, 3, 0, -6, -2, -3, 3, -9, 0, 3, 5, 1, 2, -7, -4, -3], [6, -1, -1, 0, 1, 0, 1, -2, -10, -1, 0, 4, 0, 5, 4, -4], [6, 0, 0, -4, 1, 0, 2, -10, -5, -2, -1, -2, 0, -9, -2, -4], [-6, -3, -2, -2, 2, 0, 1, 5, -3, -3, 0, -2, 0, 9, -4, 2], [1, -3, -3, -2, -1, -6, 6, 3, -2, 0, 1, 0, 2, 0, 1, 1], [-7, 1, 0, 3, -2, 0, -2, 5, 5, 2, 0, -6, 0, 3, -2, 2], [0, -6, 4, 0, 4, -3, 6, 4, 8, -3, 2, 2, 0, 2, 0, -3], [0, 4, 0, -8, 2, -1, 4, 0, 0, 1, 1, 5, -2, 5, 2, -4], [-1, 3, 0, -8, 0, 3, 3, 1, 0, -3, -2, 4, 0, -22, 0, -4], [0, 1, 0, 3, 0, 0, 0, 2, -3, -1, 0, -3, 1, 0, -6, -3], [-2, 1, -4, -2, 0, 3, -4, 6, 2, 2, -4, 0, 4, 0, -1, -2], [-3, 0, 4, 1, 1, 0, -3, -4, -7, -3, 1, 1, -4, 1, -1, -3], [0, -6, 0, 1, 0, -8, 4, 0, -3, -2, 0, 1, -1, -2, 0, 1], [-2, 0, 0, -8, 0, -4, 4, 2, 2, 0, 0, 0, 0, -4, -2, -2], [-4, -2, 0, -2, -5, -1, -2, 4, 0, 1, 0, 2, 5, 13, 2, -1], [1, -3, 1, 2, 2, -3, 0, -2, 1, -7, 5, -2, 3, 7, 7, 0], [-9, 3, 0, 1, 2, 3, -3, 13, 13, 6, 0, -2, 0, 1, -2, 2], [6, -3, -4, 2, -4, -1, 5, -1, -5, -6, -4, -4, 0, 2, -3, 3], [6, 2, 3, -3, 2, 6, 2, 6, 9, 4, 3, 6, 0, -3, 4, -4], [16, 4, 0, 2, 2, 0, 2, -8, -8, 4, 2, -4, -1, -4, -2, 4], [-8, 3, 0, -6, 0, 0, 3, 8, 0, 0, -2, 2, 0, 2, -2, -3], [-1, 4, 3, -4, 0, -4, 0, -6, 1, 0, 3, 2, -3, -7, -1, -6], [-2, 0, 2, -4, -3, 3, -2, -4, -1, 2, 3, 0, 2, -7, 0, -4], [0, 4, 1, -2, 1, 8, -4, 2, 6, 4, 0, 2, 2, 3, 4, 2], [0, -7, 0, -3, 0, -5, 12, -9, 0, -6, -1, 1, 1, -13, -1, -4], [0, -2, 5, 5, 10, -2, 0, -5, 0, -7, 5, -5, -5, 5, -3, 0], [0, -1, -3, -3, -3, -6, 3, -5, 8, -5, 0, -5, 1, 8, -2, -5], [-5, 0, -3, -4, -1, 5, 0, 17, 7, 0, 1, 3, -3, 9, 3, -4], [0, 1, 0, 10, 0, 3, 1, 0, 0, -3, 4, -2, 0, 16, 6, 5], [-4, 8, 2, -6, 4, 8, 0, -4, -4, 2, 2, 6, -2, -4, -1, 0], [0, 8, -2, -6, 1, 4, -4, 2, 3, 4, 1, 4, 2, -3, -4, -2], [0, 2, 3, -1, -2, -4, -8, -8, -5, 4, 3, 2, 0, -1, -4, 4], [10, -3, 10, 0, 5, -7, 3, -6, -6, -7, 5, -5, -5, -8, 0, -2], [18, 4, 1, 3, 1, 0, -1, -10, -5, 4, 2, 2, -1, -9, 5, -2], [-6, 2, 1, 4, 1, 0, -2, 2, 6, 2, 2, 3, -1, 5, 7, -3], [-5, 0, 0, 4, -2, 3, -3, 8, 4, 3, 2, -2, 0, 9, -2, 4], [0, 2, 2, 3, 2, 4, -2, 6, 9, 2, 0, 7, -5, 10, 4, 7], [0, -2, 1, 4, 1, 0, 0, -8, 4, 2, 0, 3, -5, 7, -1, 3], [3, 1, -1, 6, -1, -2, 2, 7, -12, 0, -1, 0, 2, 0, -1, -1], [4, 6, 4, -12, -4, 0, -4, -6, -4, 6, 0, 9, 0, -16, -3, -9], [0, 3, 0, -1, 2, 0, -4, 0, 9, 3, 2, 5, -1, -8, 4, -5], [13, 4, 4, 1, 5, 2, -1, -4, 1, 3, 5, 1, -4, -11, -1, -3], [4, 1, 5, 7, 0, 3, -3, -6, -7, 0, -5, 0, 0, -11, 6, 6], [2, -9, -1, -11, -3, -10, 10, 0, -3, 0, -5, 0, 6, -19, -7, -7], [-4, -2, -2, -2, -4, -2, 0, 2, -4, -5, -2, 2, 2, -2, 1, 0], [-9, 5, 6, 0, 1, 0, -5, -3, 12, 0, 3, -2, -5, 3, 0, 3], [-2, -1, 0, -6, 2, 0, -1, 2, 0, 0, 0, 4, -2, -6, 2, -3], [-4, 3, 6, 2, 2, 7, -7, 3, -1, 0, -2, 0, -4, 2, -1, -1], [0, 4, 2, 3, 2, 2, -1, 10, 7, -2, 0, -3, -5, 8, -6, -3], [-6, -5, 0, 1, 0, 1, 4, -3, 6, -2, 0, -1, 0, -2, 0, 2], [0, 4, -4, 3, 0, -4, 0, -7, 0, 0, -1, -5, 1, -5, -1, 8], [-9, -2, -5, 2, -5, -1, 1, 5, 9, -1, -5, -5, 5, 11, 5, 8], [10, 3, 0, 4, 5, 1, 3, -10, 0, -1, -1, -3, -5, -10, -2, 2], [-13, 0, -2, 3, -2, 4, -3, 24, 11, 3, 2, 0, -2, 16, 0, 3], [11, -2, 3, 5, 6, -2, 0, -11, 11, -2, 6, -5, 0, 16, 3, 0], [11, 3, 5, 0, 1, 4, -2, -3, 2, 6, 5, 0, 0, 0, -1, 1], [6, 2, -1, 5, -2, -1, 1, -5, -6, 0, -3, 0, 4, -9, 5, 5], [3, 0, 0, 3, -1, 0, 0, -7, 1, 0, -2, 0, 2, -5, 1, 1], [-9, -4, -8, -3, -5, -2, -1, 8, -5, -5, -5, 1, 8, 9, -1, 1], [0, 0, 5, 6, 3, 0, -4, -5, -1, 0, 8, 1, -4, 10, 7, -1], [-2, 5, 0, -8, 0, 2, 5, 2, 0, -2, -1, -2, 0, -6, -12, -4], [0, -1, -7, -1, -2, -2, 2, 6, 1, 0, 3, 0, 4, 9, -2, -2], [-4, -4, -2, 2, -4, -4, 0, 12, -4, -8, 0, -2, 4, -6, 5, 0], [-6, -4, -7, -2, -3, -2, 6, 7, 6, 2, -3, 0, 7, 8, 0, 2], [-1, 0, 2, -6, -1, 0, 2, -2, 0, -2, 1, 5, 2, -8, 5, -6], [-10, 3, 6, 0, 1, 0, -3, -2, 14, 0, 3, -7, -5, 4, 0, -2], [-8, 6, -2, 4, 2, 0, -4, 6, -2, 6, 0, -3, 0, 16, 1, 3], [6, 6, 7, -11, 3, 3, 3, -7, -13, 9, 3, 8, -7, -21, -8, -5], [2, 1, 5, -3, -2, 0, -2, -6, -1, 2, 5, 6, 0, -3, 2, -2], [-17, 0, 5, -5, 0, 0, 4, -5, 2, 4, 0, 4, -5, 7, -4, -3], [0, -4, 0, 2, 0, -4, 0, -2, 0, 1, 2, -2, 2, 6, -3, 0], [-2, 3, 2, 0, 0, -2, -3, 4, 8, -2, 1, 5, -2, 3, 0, 4], [3, 5, -3, -8, 0, -13, 8, 10, -3, -4, -5, 2, 5, -3, -3, -10], [0, 2, -3, 0, -3, 8, -4, 5, -3, 6, 0, -1, 4, 0, -1, -1], [3, -2, 1, 3, 2, -2, 0, 11, 3, 2, 4, -3, 2, -6, 1, 0], [0, 0, -2, 0, -2, 2, -1, -16, -8, 2, 0, 1, 4, -6, 1, 1], [-1, 1, 1, -8, 0, -7, 6, 0, 1, -3, -7, 2, 7, -15, -3, -10], [-12, -7, 3, 2, 1, 0, 2, 3, 3, -7, 4, 7, -2, 12, 9, -7], [-13, -5, 2, 1, 1, -4, 6, 21, 23, -10, 2, -2, 0, 1, 1, -1], [-4, 0, -3, -1, 0, 6, 6, -3, -6, 0, -3, 2, 0, -1, 3, -3], [-2, 6, 2, -10, 2, -1, 1, 10, -8, 0, 2, 0, -4, -6, -6, -6], [8, 2, 0, 0, 0, 4, -2, 12, 4, 4, 0, 4, 0, 2, 0, 5], [0, 0, 2, 0, -4, 1, 1, 11, 13, 0, 2, 0, 0, 0, 5, -5], [17, 3, 2, 0, 2, 5, -3, 15, 0, 5, 1, -5, 0, -1, 0, 3], [0, 0, 6, 1, 6, 4, -2, 0, 11, 4, 0, 1, -1, 6, 0, 1], [-5, 10, -2, -6, 3, 5, -4, 2, -10, 6, 3, 3, 2, 4, -3, 0], [-6, 1, -1, 12, 0, 11, -12, -6, 6, 6, -1, 0, 1, 5, 6, 12], [-10, -3, 0, 12, 0, 5, -2, 6, 10, 1, 0, 2, 0, 18, 7, 10], [-6, -6, 0, 12, 4, 6, -6, 6, 0, -6, -1, -5, -4, 3, 2, 6], [7, -6, 0, 8, -3, 6, -6, -7, 0, -6, -6, 2, 3, 17, 12, 4], [-1, -6, -4, 0, -1, -3, 6, 9, 6, -3, -2, 4, 3, 5, 0, -6], [20, 0, 4, 2, -3, 0, -2, -38, -17, 2, 3, 2, 4, -13, 2, 2], [5, -14, -7, 6, -3, -7, 1, 7, -7, -13, -3, -5, 7, 5, 5, 4], [-7, 6, 2, -3, 3, 6, -6, -1, 1, 12, 2, 6, 0, -3, 1, -1], [-10, 2, 3, 1, -5, 0, -2, 2, 19, 2, -2, -2, 1, -13, -1, 2], [-1, -3, -3, -16, -3, -7, 7, 10, -5, 0, -3, 0, 6, -14, -2, -2], [-5, 1, -3, -7, -6, 1, 0, -3, -5, -8, 0, 7, 6, 2, -3, 0], [18, -1, 3, 1, 0, 5, -4, -17, -18, 2, 1, 5, -1, -15, 3, -4], [-1, 0, -3, -5, -6, 0, -2, 3, -10, -2, -6, 2, 3, -7, -2, 1], [0, -4, 0, 3, 0, 8, -4, 0, -3, 12, 0, 7, 1, 0, 4, 7], [4, -1, -2, 4, 2, 0, -3, 0, -2, -1, 0, -5, 0, 4, -1, 5], [1, 4, -2, -3, -4, 4, 0, -3, 1, 9, -5, 3, -1, -1, 0, 0], [5, 5, -6, 0, -2, -4, -5, -21, -32, -4, -3, -3, 4, -13, 0, -3], [21, 1, 0, 5, 1, 3, 1, -19, -19, 2, 0, -10, 0, 5, 1, -1], [-5, 5, -2, 0, -6, 9, -5, 5, 8, 9, -1, -3, -4, 5, 0, 7], [1, 7, -4, -6, -8, 7, 0, 8, 1, 7, -2, 6, 6, -8, 12, 0]]
